# [FFXI Auction House Bot][ghWeb]

A set of command-line tools for interacting with the auction house of a private FFXI server.

Please see the [docs][ghWeb] for more information.

---

This project was originally developed for the [Darkstar][DSP] server, but it will also work with new variations below.

| FFXI Server Project | Status  |
| ------------------- | ------- |
| [Darkstar][DSP]     | defunct |
| [Topaz][TPZ]        | defunct |
| [Topaz-next][TPZN]  | defunct |
| [LandSandBoat][LSB] | current |

---

## [Features][ghWeb]

- Create a database of item prices by scraping ffxiah.com.
- Start a bot that can buy items put up for sale by players.
- The bot can also stock the auction house with items for players to buy.

---

[ghRep]: https://github.com/AdamGagorik/ffxiahbot
[ghWeb]: http://adamgagorik.github.io/ffxiahbot
[DSP]: https://github.com/DarkstarProject/darkstar
[TPZ]: https://github.com/project-topaz/topaz
[TPZN]: https://github.com/topaz-next/topaz
[LSB]: https://github.com/LandSandBoat/server
